==> rendition-9.0.0.tgz: package/dist_esm5/components/Filters/FilterDescription.js <==
import * as tslib_1 from "tslib";
import noop from 'lodash/noop';
import * as React from 'react';
import FaClose from 'react-icons/lib/fa/close';
import styled from 'styled-components';
import { Button } from '../../';
import { Box, Flex } from '../Grid';
var ButtonWrapper = styled.button(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\tfont-size: 13px;\n\tmin-height: 22px;\n\tborder: 0;\n\tborder-radius: 3px;\n\tbackground-color: #e9e9e9;\n\tpadding: 3px 8px;\n"], ["\n\tfont-size: 13px;\n\tmin-height: 22px;\n\tborder: 0;\n\tborder-radius: 3px;\n\tbackground-color: #e9e9e9;\n\tpadding: 3px 8px;\n"])));
var WrappingEm = styled.em(templateObject_2 || (templateObject_2 = tslib_1.__makeTemplateObject(["\n\twhite-space: pre-wrap;\n"], ["\n\twhite-space: pre-wrap;\n"])));
var DeleteButton = styled(Button)(templateObject_3 || (templateObject_3 = tslib_1.__makeTemplateObject(["\n\tcolor: rgba(0, 0, 0, 0.4);\n"], ["\n\tcolor: rgba(0, 0, 0, 0.4);\n"])));
var FilterDescriptionInner = function (props) { return (React.createElement(Box, null,
    !!props.filter.anyOf &&
        props.filter.anyOf.map(function (f, i) { return (React.createElement(React.Fragment, { key: i },
            i > 0 && React.createElement(WrappingEm, null, " or "),
            React.createElement("span", null, f.description))); }),
    !props.filter.anyOf && React.createElement("span", null, props.filter.description))); };
var FilterDescription = function (props) {
    return (React.createElement("div", null,
        React.createElement(ButtonWrapper, { onClick: !!props.edit ? props.edit : noop },
            React.createElement(Flex, null,
                React.createElement(FilterDescriptionInner, { filter: props.filter }))),
        !!props.delete && (React.createElement(DeleteButton, { plain: true, p: 1, fontSize: 1, ml: 1, color: props.dark ? '#fff' : undefined, onClick: props.delete },
            React.createElement(FaClose, null)))));
};
export default FilterDescription;
var templateObject_1, templateObject_2, templateObject_3;

==> rendition-9.4.0.tgz: package/dist_esm5/components/Filters/FilterDescription.js <==
import * as tslib_1 from "tslib";
import noop from 'lodash/noop';
import * as React from 'react';
import FaClose from 'react-icons/lib/fa/close';
import styled from 'styled-components';
import { Button } from '../../';
import { Box, Flex } from '../Grid';
var ButtonWrapper = styled.button(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\tfont-size: 13px;\n\tmin-height: 22px;\n\tborder: 0;\n\tborder-radius: 3px;\n\tbackground-color: #e9e9e9;\n\tpadding: 3px 8px;\n"], ["\n\tfont-size: 13px;\n\tmin-height: 22px;\n\tborder: 0;\n\tborder-radius: 3px;\n\tbackground-color: #e9e9e9;\n\tpadding: 3px 8px;\n"])));
var WrappingEm = styled.em(templateObject_2 || (templateObject_2 = tslib_1.__makeTemplateObject(["\n\twhite-space: pre-wrap;\n"], ["\n\twhite-space: pre-wrap;\n"])));
var DeleteButton = styled(Button)(templateObject_3 || (templateObject_3 = tslib_1.__makeTemplateObject(["\n\tcolor: rgba(0, 0, 0, 0.4);\n"], ["\n\tcolor: rgba(0, 0, 0, 0.4);\n"])));
var FilterDescriptionInner = function (props) { return (React.createElement(Box, null,
    !!props.filter.anyOf &&
        props.filter.anyOf.map(function (f, i) { return (React.createElement(React.Fragment, { key: i },
            i > 0 && React.createElement(WrappingEm, null, " or "),
            React.createElement("span", null, f ? f.description : ''))); }),
    !props.filter.anyOf && React.createElement("span", null, props.filter.description))); };
var FilterDescription = function (props) {
    return (React.createElement("div", null,
        React.createElement(ButtonWrapper, { onClick: !!props.edit ? props.edit : noop },
            React.createElement(Flex, null,
                React.createElement(FilterDescriptionInner, { filter: props.filter }))),
        !!props.delete && (React.createElement(DeleteButton, { plain: true, p: 1, fontSize: 1, ml: 1, color: props.dark ? '#fff' : undefined, onClick: props.delete },
            React.createElement(FaClose, null)))));
};
export default FilterDescription;
var templateObject_1, templateObject_2, templateObject_3;
